==> scorched3d_38.1.orig.tar.gz: scorched3d-38.1/src/tank/TankAccessories.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_TANKACCESSORIES_H__60850A18_DED2_4BB0_B104_CB0941EF6D1D__INCLUDED_)
#define AFX_TANKACCESSORIES_H__60850A18_DED2_4BB0_B104_CB0941EF6D1D__INCLUDED_

#include <tank/TankWeapon.h>
#include <tank/TankParachutes.h>
#include <tank/TankShields.h>
#include <tank/TankAutoDefense.h>
#include <tank/TankBatteries.h>
#include <tank/TankFuel.h>

class ScorchedContext;
class TankAccessories  
{
public:
	TankAccessories(ScorchedContext &context);
	virtual ~TankAccessories();

	void reset();
	void newGame(); // Called at the start of each game
	void add(Accessory *accessory);
	void rm(Accessory *accessory);

	int getAccessoryCount(Accessory *accessory);
	std::list<Accessory *> getAllAccessories(bool sort=false);

	TankFuel &getFuel() { return tankFuel_; }
	TankWeapon &getWeapons() { return tankWeapon_; }
	TankParachutes &getParachutes() { return tankPara_; }
	TankShields &getShields() { return tankShield_; }
	TankAutoDefense &getAutoDefense() { return tankAuto_; }
	TankBatteries &getBatteries() { return tankBatteries_; }

	// Serialize the tank accessories
	bool writeMessage(NetBuffer &buffer);
	bool readMessage(NetBufferReader &reader);

protected:
	ScorchedContext &context_;
	TankFuel tankFuel_;
	TankWeapon tankWeapon_;
	TankParachutes tankPara_;
	TankShields tankShield_;
	TankAutoDefense tankAuto_;
	TankBatteries tankBatteries_;
};

#endif // !defined(AFX_TANKACCESSORIES_H__60850A18_DED2_4BB0_B104_CB0941EF6D1D__INCLUDED_)

==> scorched3d_41.2dfsg.orig.tar.gz: scorched3d-41.2dfsg/src/tank/TankAccessories.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_TANKACCESSORIES_H__60850A18_DED2_4BB0_B104_CB0941EF6D1D__INCLUDED_)
#define AFX_TANKACCESSORIES_H__60850A18_DED2_4BB0_B104_CB0941EF6D1D__INCLUDED_

#include <weapons/AccessoryPart.h>
#include <tank/TankWeapon.h>
#include <tank/TankAutoDefense.h>
#include <tank/TankBatteries.h>

class ScorchedContext;
class TankAccessories  
{
public:
	TankAccessories(ScorchedContext &context);
	virtual ~TankAccessories();

	void setTank(Tank *tank);

	void newMatch();
	void add(Accessory *accessory, int count, bool check = true);
	void rm(Accessory *accessory, int count = 1);
	void clearAccessories();

	void activate(Accessory *accessory);

	bool accessoryAllowed(Accessory *accessory, int count);
	int getAccessoryCount(Accessory *accessory);
	void getAllAccessories(std::list<Accessory *> &result);
	std::list<Accessory *> &getAllAccessoriesByType(
		AccessoryPart::AccessoryType type);
	std::list<Accessory *> &getAllAccessoriesByGroup(
		const char *groupName);

	TankWeapon &getWeapons() { return tankWeapon_; }
	TankAutoDefense &getAutoDefense() { return tankAuto_; }
	TankBatteries &getBatteries() { return tankBatteries_; }

	// Serialize the tank accessories
	bool writeMessage(NetBuffer &buffer, bool writeAccessories);
	bool readMessage(NetBufferReader &reader);

protected:
	ScorchedContext &context_;
	TankWeapon tankWeapon_;
	TankAutoDefense tankAuto_;
	TankBatteries tankBatteries_;
	Tank *tank_;

	typedef std::list<Accessory *> AccessoryList;
	std::map<Accessory *, int> accessories_;
	std::map<std::string, AccessoryList*> accessoryGroups_;
	std::map<AccessoryPart::AccessoryType, AccessoryList*> accessoryTypes_;

	void changed();
	void add_(Accessory *accessory, int count, bool check);
};

#endif // !defined(AFX_TANKACCESSORIES_H__60850A18_DED2_4BB0_B104_CB0941EF6D1D__INCLUDED_)
